@@ -4,6 +4,7 @@ import (
 	"context"
 	"errors"
 	"fmt"
+	"io"
 
 	"github.com/sirupsen/logrus"
 	"gitlab.com/gitlab-org/gitlab-runner/common/buildlogger"
@@ -74,6 +75,10 @@ type Executor interface {
 	SetCurrentStage(stage ExecutorStage)
 }
 
+type Connector interface {
+	Connect(ctx context.Context) (io.ReadWriteCloser, error)
+}
+
 type ManagedExecutorProvider interface {
 	// Init initializes the executor provider.
 	//
@@ -150,13 +155,8 @@ func (b *BuildError) Unwrap() error {
 	return b.Inner
 }
 
-func (b *BuildError) WithFailureReason(reason JobFailureReason) *BuildError {
-	b.FailureReason = reason
-	return b
-}
-
 // MakeBuildError returns an new instance of BuildError.
-func MakeBuildError(format string, args ...interface{}) *BuildError {
+func MakeBuildError(format string, args ...interface{}) error {
 	return &BuildError{
 		Inner: fmt.Errorf(format, args...),
 	}
