@@ -15,7 +15,6 @@ import (
 
 	"github.com/sirupsen/logrus"
 
-	"gitlab.com/gitlab-org/gitlab-runner/helpers/featureflags"
 	url_helpers "gitlab.com/gitlab-org/gitlab-runner/helpers/url"
 	"gitlab.com/gitlab-org/gitlab-runner/helpers/vault/auth_methods"
 )
@@ -472,6 +471,13 @@ func (ido *ImageDockerOptions) UnmarshalJSON(data []byte) error {
 	return nil
 }
 
+func (ido *ImageDockerOptions) Expand(vars JobVariables) ImageDockerOptions {
+	return ImageDockerOptions{
+		Platform: vars.ExpandValue(ido.Platform),
+		User:     StringOrInt64(vars.ExpandValue(string(ido.User))),
+	}
+}
+
 func (iko *ImageKubernetesOptions) UnmarshalJSON(data []byte) error {
 	type imageKubernetesOptions ImageKubernetesOptions
 	inner := imageKubernetesOptions{}
@@ -485,6 +491,12 @@ func (iko *ImageKubernetesOptions) UnmarshalJSON(data []byte) error {
 	return nil
 }
 
+func (iko *ImageKubernetesOptions) Expand(vars JobVariables) ImageKubernetesOptions {
+	return ImageKubernetesOptions{
+		User: StringOrInt64(vars.ExpandValue(string(iko.User))),
+	}
+}
+
 func (iko *ImageKubernetesOptions) GetUIDGID() (int64, int64, error) {
 	if iko.User == "" {
 		return 0, 0, nil
@@ -793,14 +805,11 @@ func (j *JobResponse) ValidateStepsJobRequest(executorSupportsNativeSteps bool)
 		return fmt.Errorf("the `run` keyword requires the exclusive use of the variable STEPS")
 	}
 
-	if j.Image.Name == "" {
-		// Experiment requires step-runner to be present in
-		// the container image. If no image is provided then
-		// we use the step-runner v0 image.
-		j.Image.Name = "registry.gitlab.com/gitlab-org/step-runner:v0"
-	}
+	if executorSupportsNativeSteps {
+		// If the executor supports native step execution and the job was specified as steps, execute the job via native
+		// steps integration. In other words, disallow executing the job in shim mode if the executor supports native
+		// steps.
 
-	if executorSupportsNativeSteps && j.NativeStepsRequested() {
 		// If native steps is enabled, the script steps won't be executed anyway, but this change ensures the job log
 		// trace is coherent since it will print: Executing "step_run" stage of the job script
 		j.Steps = Steps{{Name: StepNameRun}}
@@ -828,18 +837,6 @@ func (j *JobResponse) ValidateStepsJobRequest(executorSupportsNativeSteps bool)
 	return nil
 }
 
-func (j *JobResponse) NativeStepsRequested() bool {
-	if j.Run == "" {
-		return false
-	}
-	for _, v := range j.Variables {
-		if v.Key == featureflags.UseNativeSteps {
-			return true
-		}
-	}
-	return false
-}
-
 type Secrets map[string]Secret
 
 type Secret struct {
@@ -1083,9 +1080,21 @@ type GitLabSecretsManagerServer struct {
 // for OpenBao JWT authentication. This allows the runner to authenticate on each
 // request without storing tokens.
 type GitLabSecretsManagerServerInlineAuth struct {
+	// Path is the full path for this login request. This is assumed to be
+	// against an OpenBao auth method that takes a role and jwt parameter;
+	// or, roughly equivalent semantic as the JWT auth engine.
+	Path string `json:"path"`
+
+	// JWT is the JWT to use to authenticate against the OpenBao server.
+	JWT string `json:"jwt"`
+
+	// Role is the required login authentication role.
+	Role string `json:"role"`
+
+	// AuthMount is a legacy field sent on older GitLab versions and must be
+	// templated to auth/<auth_mount>/login. Newer server versions send the
+	// full request path to authenticate via.
 	AuthMount string `json:"auth_mount"`
-	JWT       string `json:"jwt"`
-	Role      string `json:"role"`
 }
 
 // GitLabSecretsManagerEngine specifies the secret engine configuration in OpenBao,
